#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509-system
version:              1.6.6
visibility:           public
id:                   x509-system-1.6.6-K1fu1FZo29Y4bjI2V2mTCG
key:                  x509-system-1.6.6-K1fu1FZo29Y4bjI2V2mTCG
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             Handle per-operating-system X.509 accessors and storage
description:          System X.509 handling
category:             Data
abi:                  2c53b8b6319e4b180c892729073b2910
exposed:              True
exposed-modules:      System.X509 System.X509.MacOS System.X509.Unix
import-dirs:          /usr/lib/ghc-8.10.5/site-local/x509-system-1.6.6
library-dirs:         /usr/lib/ghc-8.10.5/site-local/x509-system-1.6.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/x509-system-1.6.6
hs-libraries:         HSx509-system-1.6.6-K1fu1FZo29Y4bjI2V2mTCG
depends:
    base-4.14.2.0 bytestring-0.10.12.0 containers-0.6.4.1
    directory-1.3.6.0 filepath-1.4.2.1 mtl-2.2.2
    pem-0.2.4-2wQc93Rt7UuIV4uoSJd8MA process-1.6.9.0
    x509-1.7.5-FcakXsO5AZG8CA3iSGWvZR
    x509-store-1.6.7-ISQ8liWEiGzKnOu2j78UBb

haddock-interfaces:   /usr/share/doc/haskell-x509-system/html/x509-system.haddock
haddock-html:         /usr/share/doc/haskell-x509-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

